Welcome to the Selectize bug tracker. Thank you for taking the time to
make Selectize a better library!

Please keep in mind this repository has an important issue backlog and
that maintainers have limited time to fix issues, triage, and understand
them.

If you've never done so, please read the
[guide to reporting issues](https://github.com/selectize/selectize.js/wiki/Reporting-issues-guide)
in the Wiki to help us better understand your issue.

Place an `x` in the checklist steps (`[ ]` becomes `[x]`) to demonstrate
you have done/verified all the steps you needed to do.

Thank you for reading this! You can now erase everything up to the
following dashes, and then complete what's after.

ISSUES THAT EITHER:

* IGNORE THE ISSUE GUIDELINES
* ERASE THE FOLLOWING TEMPLATE
* DON'T FOLLOW THE PROPER NUMBERED FORMAT FOR STEPS TO REPRODUCE

COULD BE CLOSED.

---

I did:

* [ ] Search for if my issue has already been submitted
* [ ] Make sure I'm reporting something precise that needs to be fixed
* [ ] Give my issue a descriptive and concise title
* [ ] Create a *minimal* working example on JsFiddle or Codepen
	(or gave a link to a demo on the Selectize docs)
* [ ] Indicate *precise* steps to reproduce in *numbers* and the result,
	  like below

[replace me with a short description of issue]

Steps to reproduce:

1.
2.
3.

Expected result:

Actual result:

[you can add explanations here of the context/what you were trying to
do, and if you have findings about what the cause might be]
